import ts from "typescript";
/**
 * Cases:
 *  1. import { element } from "library";  // Named import
 *  2. import element, { another } from "library";  // Named import + Default import
 *  3. import * as lib from "library";  // Namespace import
 *  4. import "library";  // No import clause => Direct import
 *  5. import library from "library";  // Default import
 *  6. import { } from "library";  // Named import
 */
export declare enum ImportType {
    Named = 0,
    Namespace = 1,
    Default = 2,
    Direct = 3
}
export interface ImportElement {
    type: ImportType;
    name: string;
    package: string;
}
export declare class ImportStore {
    private elements;
    constructor(elements?: ImportElement[]);
    update(elems: ImportElement[]): void;
    searchElement(target: string): ImportElement | undefined;
    listAllElementsByType(type: ImportType): ImportElement[];
}
/**
 * Extract all import elements from one import statement for every type.
 */
export declare function extractImportElements(sourceFile: ts.SourceFile, importStat: ts.ImportDeclaration): ImportElement[];
export declare function genImportStats(depElems: ImportElement[]): string[];
export declare function buildImportStore(sourceFile: ts.SourceFile): ImportStore;
